@@ -5,11 +5,12 @@ import json
 import os
 import shutil
 import tempfile
-from pathlib import Path
+from json import JSONDecodeError
 from typing import Dict
 
 import requests
 from deepchainapps import log
+from deepchainapps.utils.common import _create_apps_file, _create_deechpain_folder
 
 
 def save_app(app_name: str, dest_path: str) -> None:
@@ -17,14 +18,20 @@ def save_app(app_name: str, dest_path: str) -> None:
     Save complete path where the app is stored
     The app can be deploy next from any folder
     """
-    path = Path.home().joinpath(".deep-chain").joinpath("config")
+    root_path = _create_deechpain_folder()
+    path = _create_apps_file(root_path)
+
     data = {}
-    with open(path, "r") as config_file:
-        data = json.load(config_file)
+    with open(path, "r+") as app_file:
+        try:
+            data = json.load(app_file)
+        except JSONDecodeError:
+            pass
 
-    with open(path, "w") as config_file:
         data[app_name] = {"dir": os.path.abspath(dest_path), "status": "local"}
-        json.dump(data, config_file)
+        app_file.seek(0)  # reset file position to the beginning.
+        json.dump(data, app_file)
+        app_file.truncate()  # remove remaining part
 
 
 def create_base_app(args) -> None:
@@ -61,7 +68,7 @@ def download_latest_version(latest_release: Dict, temp_dir: str) -> None:
     Function do downlad latest tarball image on github where templates are stored.
     repo link : https://github.com/instadeepai/deep-chain-apps
     """
-    log.info(f'downloading release  from : {latest_release["tarball_url"]}')
+    log.info("downloading release  from : %s", latest_release["tarball_url"])
     req = requests.get(latest_release["tarball_url"])
     with open(f"{temp_dir}/{latest_release['tag_name']}.tar", "wb") as file:
         file.write(req.content)
