@@ -26,6 +26,8 @@ SequenceProbs = List[Probs]
 
 
 class TransformersApp:
+    """Class provide embedding, logelikelihood function"""
+
     def __init__(
         self, device: str, model_uri: str = None, model_type: str = "esm1_t6_43M_UR50S"
     ):
@@ -42,7 +44,7 @@ class TransformersApp:
             )
             sleep(2)
         try:
-            fn = getattr(pretrained, model_type)
+            model_fn = getattr(pretrained, model_type)
         except:
             msg = (
                 f"Couldn't find model type {model_type} in backend "
@@ -50,7 +52,7 @@ class TransformersApp:
             )
             raise ImportError(msg)
 
-        self.model, self.token = fn()
+        self.model, self.token = model_fn()
         self.model = self.model.to(self.device)
         self.emb_version = int(re.findall(PATTERN, model_type)[0])
 
@@ -58,7 +60,7 @@ class TransformersApp:
     def list_esm_backend(cls) -> None:
         """Get all possible backend for the ESM model"""
 
-        log.info(f"Use ESM backend in this list {' / '.join(BACKEND)}")
+        log.info("Use ESM backend in this list %s", " / ".join(BACKEND))
 
     def _predict(self, sequences: List[str], type: str = "logits") -> np.array:
         """Return the model prediction of a sequence of Am.Ac."""
@@ -68,7 +70,9 @@ class TransformersApp:
         batch_labels, batch_strs, batch_tokens = batch_converter(sequences)
 
         with torch.no_grad():
-            output = self.model(batch_tokens, repr_layers=[self.emb_version])
+            output = self.model(
+                batch_tokens.to(self.device), repr_layers=[self.emb_version]
+            )
 
         if type == "logits":
             output = output["logits"]
@@ -77,7 +81,7 @@ class TransformersApp:
                 output["representations"][self.emb_version].detach()[:, :, :].mean(1)
             )
 
-        return output
+        return output.detach().cpu().numpy()
 
     def _softmaxbh(self, x: torch.Tensor) -> np.array:
         """Compute softmax values for each sets of scores in x."""
@@ -87,12 +91,10 @@ class TransformersApp:
 
     def predict_embedding(self, sequences: List[str]) -> np.ndarray:
         pred = self._predict(sequences, type="representations")
-        pred = pred.detach().cpu().numpy()
         return pred
 
     def predict_logits(self, sequences: List[str]) -> np.ndarray:
         pred = self._predict(sequences, type="logits")
-        pred = pred.detach().cpu().numpy()
         return pred
 
     def _compute_loglikelihood(self, scores: List[float]) -> np.array:
